<?php

namespace Litepie\Location\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litepie\Location\Interfaces\CountryRepositoryInterface;
use Litepie\Location\Repositories\Eloquent\Filters\CountryPublicFilter;
use Litepie\Location\Repositories\Eloquent\Presenters\CountryListPresenter;

class CountryPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        CountryRepositoryInterface $country
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litepie.location.modules'), 'country', guard_url('country'));
        $this->repository = $country;
    }

    /**
     * Show country's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(CountryPublicFilter::class)
            ->setPresenter(CountryListPresenter::class)
            ->select('countries.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('location::country.names'))
            ->view('location::public.country.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show country.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('location::country.name'))
            ->view('location::public.country.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
